@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Glorified metronome
 
-our $VERSION = '0.0600';
+our $VERSION = '0.0601';
 
 use Moo;
 use MIDI::Simple;
@@ -88,7 +88,7 @@ sub rest { return shift->score->r(@_) }
 
 sub count_in {
     my $self = shift;
-    my $bars = shift || 1;
+    my $bars = shift || $self->bars;
     for my $i ( 1 .. $self->beats * $bars) {
         $self->note( $self->quarter, $self->closed_hh );
     }
@@ -130,19 +130,19 @@ MIDI::Drummer::Tiny - Glorified metronome
 
 =head1 VERSION
 
-version 0.0600
+version 0.0601
 
 =head1 SYNOPSIS
 
  use MIDI::Drummer::Tiny;
  my $d = MIDI::Drummer::Tiny->new(
     file      => 'drums.mid',
-    bpm       => 120,
+    bpm       => 100,
     signature => '3/4',
     bars      => 32,
     patch     => 26, # TR808
  );
- $d->count_in();
+ $d->count_in(1);
  $d->note( $d->quarter, $d->open_hh, $_ % 2 ? $d->kick : $d->snare )
     for 1 .. $d->beats * $d->bars;  # Alternate beats
  $d->metronome();  # <- Similar but honoring time signature
@@ -304,16 +304,25 @@ This method takes the same arguments as with L<MIDI::Simple/"Parameters for n/r/
  $d->count_in($bars);
 
 Play the closed hihat for the number of beats times the given bars.
-If no bars are given, the default of 1 is used.
+If no bars are given, the default times the number of beats is used.
 
 =head2 metronome()
 
+  $d->metronome;
+  $d->metronome($bars);
+
 Add a steady beat to the score.
 
 =head2 write()
 
 Output the score to the F<*.mid> file given in the constuctor.
 
+=head1 SEE ALSO
+
+L<Moo>
+
+L<MIDI::Simple>
+
 =head1 AUTHOR
 
 Gene Boggs <gene@cpan.org>
